From 7e48bdf4e952f7b700e64e4cd8cb190bfc630ef9 Mon Sep 17 00:00:00 2001
From: mcramer <m.cramer@pixcept.de>
Date: Wed, 31 Oct 2012 07:42:05 -0400
Subject: [PATCH] Fixed: Follow-up to commit r3623  - entered all missing german and english entries for datalog status  - excluded some more tables from status display  - inserted the info-display code to the relevant templates

---
 interface/web/sites/web_subdomain_list.php |    9 +++------
 1 files changed, 3 insertions(+), 6 deletions(-)

diff --git a/interface/web/sites/web_subdomain_list.php b/interface/web/sites/web_subdomain_list.php
index e104ace..f5feaf7 100644
--- a/interface/web/sites/web_subdomain_list.php
+++ b/interface/web/sites/web_subdomain_list.php
@@ -41,17 +41,14 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 $app->uses('listform_actions');
 
 // Limit the results to alias domains
 $app->listform_actions->SQLExtWhere = "type = 'subdomain'";
-
+$app->listform_actions->SQLOrderBy = 'ORDER BY domain';
 $app->listform_actions->onLoad();
 
 

--
Gitblit v1.9.1